package com.xinyilu.system.service.personalcheckreport;

import com.xinyilu.common.core.domain.AjaxResult;
import com.xinyilu.system.domain.dto.PersonalExamineAndApproveDTO;
import com.xinyilu.system.domain.dto.UploadPersonalCheckReportDTO;
import com.xinyilu.system.domain.personalcheckreport.PersonalCheckReport;
import com.xinyilu.system.domain.vo.personalcheckreport.PersonalCheckReportVO;
import com.xinyilu.system.domain.vo.personalcheckreport.PersonalExamineAndApproveVO;

import javax.servlet.http.HttpServletResponse;
import java.util.List;


/**
 * 个人体质检测报告Service接口
 *
 * @author xinyilu
 * @date 2022-09-22
 */
public interface IPersonalCheckReportService {
    /**
     * 查询个人体质检测报告
     *
     * @param id 个人体质检测报告主键
     * @return 个人体质检测报告
     */
    public PersonalCheckReport selectPersonalCheckReportById(Long id);

    /**
     * 查询个人体质检测报告列表
     *
     * @param personalCheckReport 个人体质检测报告
     * @return 个人体质检测报告集合
     */
    public List<PersonalCheckReportVO> selectPersonalCheckReportList(PersonalCheckReportVO personalCheckReport);

    /**
     * 个人体质检测报告,一键审核功能-列表(无分页)
     *
     * @param personalCheckReport 个人体质检测报告
     * @return 个人体质检测报告集合
     */
    public List<PersonalExamineAndApproveDTO> selectPersonalCheckReportListAll(PersonalExamineAndApproveVO personalCheckReport);

    /**
     * 新增个人体质检测报告
     *
     * @param personalCheckReport 个人体质检测报告
     * @return 结果
     */
    public int insertPersonalCheckReport(PersonalCheckReport personalCheckReport);

    /**
     * 修改个人体质检测报告
     *
     * @param personalCheckReport 个人体质检测报告
     * @return 结果
     */
    public AjaxResult updatePersonalCheckReport(PersonalCheckReport personalCheckReport);

    /**
     * 批量删除个人体质检测报告
     *
     * @param ids 需要删除的个人体质检测报告主键集合
     * @return 结果
     */
    public int deletePersonalCheckReportByIds(Long[] ids);

    /**
     * 删除个人体质检测报告信息
     *
     * @param id 个人体质检测报告主键
     * @return 结果
     */
    public int deletePersonalCheckReportById(Long id);

    /**
     * 审核报告预览下载
     *
     * @param response 相应消息
     * @param id       个人体质检测报告id
     */
    void downLoadAddress(Long id, HttpServletResponse response);

    /**
     * 判断当前学生有没有生成报告信息
     *
     * @param studentId 学生id
     * @param batchCode 批次编号
     * @return 结果
     */
    AjaxResult existCheckReport(Long studentId, String batchCode);

    /**
     * 上传个人学生报告信息
     *
     * @param checkReportDTO 输入参数信息
     * @return 上传结果
     * @throws Exception 异常信息
     */
    AjaxResult uploadPersonalCheckReport(UploadPersonalCheckReportDTO checkReportDTO) throws Exception;
}
